@@ -21,4 +21,4 @@ OC.L10N.register(
     "Link" : "Link",
     "Folder" : "قىسقۇچ"
 },
-"nplurals=1; plural=0;");
+"nplurals=2; plural=(n != 1);");
