@@ -165,7 +165,7 @@ export default {
 		{ commit, dispatch, state },
 		{ bookmark, oldFolder, newFolder }
 	) {
-		if (oldFolder === newFolder) {
+		if (Number(oldFolder) === Number(newFolder)) {
 			return
 		}
 		commit(mutations.FETCH_START, { type: 'moveBookmark' })
@@ -232,11 +232,11 @@ export default {
 			throw err
 		}
 	},
-	[actions.IMPORT_BOOKMARKS]({ commit, dispatch, state }, file) {
+	[actions.IMPORT_BOOKMARKS]({ commit, dispatch, state }, { file, folder }) {
 		const data = new FormData()
 		data.append('bm_import', file)
 		return axios
-			.post(url(state, `/bookmark/import`), data)
+			.post(url(state, `/folder/${folder || -1}/import`), data)
 			.then(response => {
 				if (!response.data || response.data.status !== 'success') {
 					if (response.status === 413) {
@@ -487,7 +487,7 @@ export default {
 			throw err
 		}
 	},
-	async [actions.DELETE_SELECTION]({ commit, dispatch, state }) {
+	async [actions.DELETE_SELECTION]({ commit, dispatch, state }, { folder }) {
 		commit(mutations.FETCH_START, { type: 'deleteSelection' })
 		try {
 			for (const folder of state.selection.folders) {
@@ -495,7 +495,7 @@ export default {
 			}
 
 			for (const bookmark of state.selection.bookmarks) {
-				await dispatch(actions.DELETE_BOOKMARK, { id: bookmark.id })
+				await dispatch(actions.DELETE_BOOKMARK, { id: bookmark.id, folder })
 			}
 			commit(mutations.FETCH_END, 'deleteSelection')
 		} catch (err) {
